@@ -5,6 +5,6 @@ Lightweight Python Build Tool
 __authors__ = ['Raghunandan Rao', "Calum J. Eadie"]
 __license__ = "MIT License"
 __contact__ = "https://github.com/rags/pynt"
-from ._pynt import task, ignore, build
+from ._pynt import task,  build
 
-__all__ = ["task", "ignore", "build"]
\ No newline at end of file
+__all__ = ["task",  "build"]
\ No newline at end of file
